==> touch-dnd-1.0.0.tgz: package/README.md <==
# touch-dnd

Advanced touch-compatible Drag'n'Drop library providing Draggable, Droppable and Sortable for Zepto.js and jQuery (for Zepto, you have to include its `data` module).

[![NPM](http://img.shields.io/npm/v/touch-dnd.svg?style=flat)](https://npmjs.org/package/touch-dnd)


**Status:** Tested with current version of Chrome (Mac & Android), Safari (Mac & iOS), Opera Next, Firefox and IE  
**Documentation:** [ma.rkusa.st/touch-dnd](http://ma.rkusa.st/touch-dnd)

#### Why?

This library is a derivative of [zepto-dnd](https://github.com/rkusa/zepto-dnd), which reached the limits of the native HTML5 Drag'n'Drop API, especially in terms of dragging helper accessibility and - most important - in terms of compatiblity with touch devices.

#### Features

* Draggable, Droppable & Sortable
* **touch compatibility**
* utilizes CSS3 [`transform`](http://www.w3schools.com/cssref/css3_pr_transform.asp) and [`transition`](http://www.w3schools.com/css/css3_transitions.asp) property for moving draggables around
* [Zepto.js](http://zeptojs.com/) compatibility

## MIT License
Copyright (c) 2013-2015 Markus Ast

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> touch-dnd-1.2.0.tgz: package/README.md <==
# touch-dnd

Advanced touch-compatible Drag'n'Drop library providing Draggable, Droppable and Sortable for Zepto.js and jQuery
(for Zepto, you have to include its `data` module).

[![NPM](http://img.shields.io/npm/v/touch-dnd.svg?style=flat)](https://npmjs.org/package/touch-dnd)

**Status:** Tested with current version of Chrome (Mac & Android), Safari (Mac & iOS), Opera Next, Firefox and IE  
**Documentation:** [ma.rkusa.st/touch-dnd](http://ma.rkusa.st/touch-dnd)

#### Why?

This library is a derivative of [zepto-dnd](https://github.com/rkusa/zepto-dnd), which reached the limits of the native
HTML5 Drag'n'Drop API, especially in terms of dragging helper accessibility and - most important - in terms of
compatiblity with touch devices.

#### Features

- Draggable, Droppable & Sortable
- **touch compatibility**
- utilizes CSS3 [`transform`](http://www.w3schools.com/cssref/css3_pr_transform.asp) and
  [`transition`](http://www.w3schools.com/css/css3_transitions.asp) property for moving draggables around
- [Zepto.js](http://zeptojs.com/) compatibility

## MIT License

Copyright (c) 2013-2018 Markus Ast

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
